@@ -4,8 +4,17 @@
 #include <string.h>
 #include <stdio.h>
 
+#include <glib/gstdio.h>
+
 #include "orbit-options.h"
 
+#ifdef G_OS_WIN32
+extern const gchar *ORBit_win32_system_rcfile;
+
+#undef ORBIT_SYSTEM_RCFILE
+#define ORBIT_SYSTEM_RCFILE ORBit_win32_system_rcfile
+#endif
+
 #undef DEBUG
 
 /*
@@ -44,6 +53,9 @@ ORBit_option_set (const ORBit_option *option,
 	case ORBIT_OPTION_INT:
 		*(gint *)option->arg = atoi (val);	
 		break;
+	case ORBIT_OPTION_ULONG:
+		*(guint *)option->arg = strtoul(val, (char **)NULL, 10);	
+		break;
 	case ORBIT_OPTION_STRING: {
 		gchar **str_arg = (char **) option->arg;
 
@@ -106,7 +118,7 @@ ORBit_option_rc_parse (const gchar         *rcfile,
 	gchar  line [1024];
 	FILE  *fh;
 
-	fh = fopen (rcfile, "r");
+	fh = g_fopen (rcfile, "r");
 	if (!fh)
 		return;
 
@@ -282,12 +294,13 @@ ORBit_option_parse (int                 *argc,
 
 	if (!no_userrc) {
 		gchar *rcfile;
+		const gchar *home = g_get_home_dir ();
 
-		rcfile = g_strdup_printf ("%s/%s", g_get_home_dir (), ORBIT_USER_RCFILE);
-
-		ORBit_option_rc_parse (rcfile, option_list);
-
-		g_free (rcfile);
+		if (home != NULL) {
+			rcfile = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", home, ORBIT_USER_RCFILE);
+			ORBit_option_rc_parse (rcfile, option_list);
+			g_free (rcfile);
+		}
 	}
 
 	ORBit_option_command_line_parse (argc, argv, option_list);
